@@ -2,7 +2,8 @@ from dataclasses import dataclass
 from datetime import date
 from typing import Optional, Type
 
-from marshmallow import EXCLUDE, Schema, fields, post_load
+from loguru import logger
+from marshmallow import EXCLUDE, Schema, fields, post_load, pre_load
 
 from snatch.base.data import BaseData
 from snatch.base.data_source import BaseSnatch
@@ -141,8 +142,14 @@ class BancoCentralSerializer(BaseSchema):
     risk_total = fields.Float(allow_none=True)
     payload = fields.Dict(allow_none=True)
 
+    @pre_load
+    def log_received_data(self, data, **kwargs):
+        logger.debug(f"Request Data received is: {data}")
+        return data
+
     @post_load
     def make_data(self, data, **kwargs):
+        logger.debug(f"Deserialized Data received is: {data}")
         new_data = BancoCentralData(**data)
         new_data.datasource_base_url = BancoCentral.base_url
         return new_data
