@@ -26,10 +26,11 @@ class BaseData:
     * status_reason (str):          The human friendly reason for current status
     * prospect_date (datetime):     The prospect datetime.
     * payload (dict):               Original payload received from prospection.
-    * timeit                        Time in seconds for retrieving data.
+    * timeit                        Time for retrieving data.
     * datasource_base_url           Data Source Base Url
     * current_environment           Current AWS Environment. Available environments are:
                                     local, dev, staging, production. Default: production
+    * data_type                     DataSource Object Name
     """
 
     tax_id: Optional[str] = None
@@ -37,11 +38,16 @@ class BaseData:
     status_reason: str = ""
     prospect_date: Optional[datetime] = None
     payload: Optional[Dict[str, Any]] = None
-    timeit: Optional[float] = None
+    timeit: Optional[str] = None
     datasource_base_url: Optional[str] = None
     current_environment: Optional[Cut] = None
 
-    def find_current_status(self, max_days_old: int):
+    @property
+    def data_type(self) -> str:
+        """Return DataSource Object Name."""
+        return self.__class__.__name__
+
+    def find_current_status(self, max_days_old: int, max_periods_old: int):
         """Find current Status for Data.
 
         Current available status:
@@ -58,11 +64,24 @@ class BaseData:
         * TIMEOUT     When timeout occurs
 
         :param max_days_old: Max days old for current data, for check expiration.
+        :param max_periods_old: Max months old for current data, for check expiration.
         """
         if self.integration_status == "SUCCESS":
             days_old = (arrow.utcnow() - arrow.get(self.prospect_date)).days
-            self.integration_status = (
-                "EXPIRED" if days_old > max_days_old else "SUCCESS"
+            months_old = days_old / 30
+            expired_by_date = days_old > max_days_old
+            expired_by_period = (
+                max_periods_old is not None and months_old > max_periods_old
             )
+            self.integration_status = (
+                "EXPIRED" if expired_by_date or expired_by_period else "SUCCESS"
+            )
+            if expired_by_period or expired_by_period:
+                self.integration_status = "EXPIRED"
+                self.status_reason = (
+                    f"Expired by Date: {days_old} old"
+                    if expired_by_date
+                    else f"Expired by Period: {months_old} months old"
+                )
         if self.integration_status in ["PENDING", "RUNNING"]:
             self.integration_status = "WAITING"
