@@ -125,6 +125,7 @@ class BaseSnatch:
         data_obj = self.serializer_class().load(data)
         data_obj.current_environment = self.settings["current_environment"]
         data_obj.datasource_base_url = self.base_url
+        logger.info(f"Data received. Status is: {data_obj.integration_status}")
         return data_obj
 
     def _format_error_response(self, error):
@@ -146,6 +147,7 @@ class BaseSnatch:
         )
         data_obj.current_environment = self.settings["current_environment"]
         data_obj.datasource_base_url = self.base_url
+        logger.info(f"Data received. Status is: {data_obj.integration_status}")
         return data_obj
 
     def _format_timeout_response(self, url):
@@ -157,6 +159,7 @@ class BaseSnatch:
         )
         data_obj.current_environment = self.settings["current_environment"]
         data_obj.datasource_base_url = self.base_url
+        logger.info(f"Data received. Status is: {data_obj.integration_status}")
         return data_obj
 
     def _request_and_create_data(
@@ -243,13 +246,13 @@ class BaseSnatch:
             raise ValueError("Invalid TaxId")
         self.tax_id = only_numbers(self.tax_id)
 
-        if not timeout:
+        if timeout is None:
             timeout = self.default_timeout
 
-        if not max_days_old:
+        if max_days_old is None:
             max_days_old = self.default_max_days
 
-        if not max_periods_old:
+        if max_periods_old is None:
             max_periods_old = self.default_max_periods
 
         data = self._last_prospect(timeout=timeout)
@@ -260,14 +263,17 @@ class BaseSnatch:
 
         # Check Status
         if data.integration_status in ["SUCCESS", "TIMEOUT", "CONN_ERROR"]:
+            logger.info(f"Returning data. Status is: {data.integration_status}.")
             return data
 
         if data.integration_status == "WAITING":
             logger.info(f"Waiting for new data... Timeout is: {timeout} seconds.")
             wait_data = self._waiter(timeout=timeout)
+            logger.info(f"Returning data. Status is: {data.integration_status}.")
             return wait_data
 
-        # Status: NOT_FOUND, ERROR or EXPIRED
+        # Status: None, NOT_FOUND, ERROR or EXPIRED
         self._post_new_prospect(timeout)
         wait_data = self._waiter(timeout=timeout)
+        logger.info(f"Returning data. Status is: {data.integration_status}.")
         return wait_data
