@@ -1,6 +1,7 @@
 """Get Environment Secrets for Snatch."""
 import os
-from typing import Any, Dict
+import sys
+from typing import Any, Dict, Optional
 
 from dotenv import load_dotenv
 from loguru import logger
@@ -11,12 +12,18 @@ from snatch.helpers.secrets_manager import SecretManager
 load_dotenv()
 
 
-def get_environment_from_secrets_manager() -> Dict[Any, Any]:
+def get_environment_from_secrets_manager(
+    environment: str, log_level: str
+) -> Dict[Any, Any]:
     """Load settings from Secrets Manager..
 
     :return Dict[Any, Any]
     """
-    current_env = os.getenv("ENV", "production")
+    current_env = os.getenv("ENV", "production") if not environment else environment
+
+    if "local" not in current_env:
+        logger.remove()
+        logger.add(sys.stderr, level=log_level)
 
     secrets = SecretManager(
         current_environment=current_env,
@@ -29,8 +36,7 @@ def get_environment_from_secrets_manager() -> Dict[Any, Any]:
         return secrets_manager_data
 
     logger.info(
-        f"Reading settings from Secrets Manager for "
-        f"service: snatch and environment: {current_env} ..."
+        f"Reading settings from `snatch/{current_env}` (logger level: {log_level})..."
     )
 
     secrets_manager_data.update(secrets.get_project_secrets())
@@ -38,7 +44,7 @@ def get_environment_from_secrets_manager() -> Dict[Any, Any]:
     return secrets_manager_data
 
 
-def get_settings():
+def get_settings(environment: Optional[str], log_level: str):
 
     config = {
         "snatch": {
@@ -46,9 +52,19 @@ def get_settings():
             "datasource_boa_vista_url": os.getenv(
                 "SNATCH_DATASOURCE_BOA_VISTA_URL", "http://datasource_boa_vista"
             ),
+            "banco_central_secret_token": os.getenv(
+                "SNATCH_BANCO_CENTRAL_SECRET_TOKEN", "foo"
+            ),
+            "datasource_banco_central_url": os.getenv(
+                "SNATCH_DATASOURCE_BANCO_CENTRAL_URL", "http://datasource_banco_central"
+            ),
         }
     }
-    config.update(get_environment_from_secrets_manager())
+    config.update(
+        get_environment_from_secrets_manager(
+            environment=environment, log_level=log_level
+        )
+    )
 
     settings = Cut(config)
     return settings
